==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/route53profiles/ProfileAssociationReference.java <==
package software.amazon.awscdk.interfaces.route53profiles;

/**
 * A reference to a ProfileAssociation resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.route53profiles.*;
 * ProfileAssociationReference profileAssociationReference = ProfileAssociationReference.builder()
 *         .profileAssociationId("profileAssociationId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.868Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_route53profiles.ProfileAssociationReference")
@software.amazon.jsii.Jsii.Proxy(ProfileAssociationReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ProfileAssociationReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the ProfileAssociation resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProfileAssociationId();

    /**
     * @return a {@link Builder} of {@link ProfileAssociationReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProfileAssociationReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ProfileAssociationReference> {
        java.lang.String profileAssociationId;

        /**
         * Sets the value of {@link ProfileAssociationReference#getProfileAssociationId}
         * @param profileAssociationId The Id of the ProfileAssociation resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profileAssociationId(java.lang.String profileAssociationId) {
            this.profileAssociationId = profileAssociationId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProfileAssociationReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ProfileAssociationReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProfileAssociationReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProfileAssociationReference {
        private final java.lang.String profileAssociationId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.profileAssociationId = software.amazon.jsii.Kernel.get(this, "profileAssociationId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.profileAssociationId = java.util.Objects.requireNonNull(builder.profileAssociationId, "profileAssociationId is required");
        }

        @Override
        public final java.lang.String getProfileAssociationId() {
            return this.profileAssociationId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("profileAssociationId", om.valueToTree(this.getProfileAssociationId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_route53profiles.ProfileAssociationReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProfileAssociationReference.Jsii$Proxy that = (ProfileAssociationReference.Jsii$Proxy) o;

            return this.profileAssociationId.equals(that.profileAssociationId);
        }

        @Override
        public final int hashCode() {
            int result = this.profileAssociationId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/route53profiles/ProfileAssociationReference.java <==
package software.amazon.awscdk.interfaces.route53profiles;

/**
 * A reference to a ProfileAssociation resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.route53profiles.*;
 * ProfileAssociationReference profileAssociationReference = ProfileAssociationReference.builder()
 *         .profileAssociationId("profileAssociationId")
 *         .resourceId("resourceId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.077Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_route53profiles.ProfileAssociationReference")
@software.amazon.jsii.Jsii.Proxy(ProfileAssociationReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ProfileAssociationReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the ProfileAssociation resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProfileAssociationId();

    /**
     * The ResourceId of the ProfileAssociation resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getResourceId();

    /**
     * @return a {@link Builder} of {@link ProfileAssociationReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProfileAssociationReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ProfileAssociationReference> {
        java.lang.String profileAssociationId;
        java.lang.String resourceId;

        /**
         * Sets the value of {@link ProfileAssociationReference#getProfileAssociationId}
         * @param profileAssociationId The Id of the ProfileAssociation resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profileAssociationId(java.lang.String profileAssociationId) {
            this.profileAssociationId = profileAssociationId;
            return this;
        }

        /**
         * Sets the value of {@link ProfileAssociationReference#getResourceId}
         * @param resourceId The ResourceId of the ProfileAssociation resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceId(java.lang.String resourceId) {
            this.resourceId = resourceId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProfileAssociationReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ProfileAssociationReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProfileAssociationReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProfileAssociationReference {
        private final java.lang.String profileAssociationId;
        private final java.lang.String resourceId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.profileAssociationId = software.amazon.jsii.Kernel.get(this, "profileAssociationId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.resourceId = software.amazon.jsii.Kernel.get(this, "resourceId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.profileAssociationId = java.util.Objects.requireNonNull(builder.profileAssociationId, "profileAssociationId is required");
            this.resourceId = java.util.Objects.requireNonNull(builder.resourceId, "resourceId is required");
        }

        @Override
        public final java.lang.String getProfileAssociationId() {
            return this.profileAssociationId;
        }

        @Override
        public final java.lang.String getResourceId() {
            return this.resourceId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("profileAssociationId", om.valueToTree(this.getProfileAssociationId()));
            data.set("resourceId", om.valueToTree(this.getResourceId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_route53profiles.ProfileAssociationReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProfileAssociationReference.Jsii$Proxy that = (ProfileAssociationReference.Jsii$Proxy) o;

            if (!profileAssociationId.equals(that.profileAssociationId)) return false;
            return this.resourceId.equals(that.resourceId);
        }

        @Override
        public final int hashCode() {
            int result = this.profileAssociationId.hashCode();
            result = 31 * result + (this.resourceId.hashCode());
            return result;
        }
    }
}
